﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;

namespace Primeval
{
    static class PauseMenu
    {
        private static Texture2D bg;
        private static Texture2D selector;

        private static Vector2[] positions;
        private static Vector2 menuPosition;

        private static Vector2 oldMousePos;

        private static int currentOption;

        private static bool selectPressed = true;
        private static bool dirPressed = true;
        private static bool quitPressed = true;

        static PauseMenu()
        {
            positions = new Vector2[3];
            positions[0] = new Vector2(50, 48);
            positions[1] = new Vector2(50, 122);
            positions[2] = new Vector2(50, 196);
        }

        public static void LoadContent()
        {
            bg = Game1.content.Load<Texture2D>("pause");
            selector = Game1.content.Load<Texture2D>("pauseselector");

            menuPosition = new Vector2(100, 300);
        }

        public static void Update(GameTime gameTime)
        {
            KeyboardState kstate = Keyboard.GetState();
            MouseState mstate = Mouse.GetState();
            GamePadState gstate = GamePad.GetState(PlayerIndex.One);

            //Mouse control
            if (oldMousePos != new Vector2(mstate.X, mstate.Y)
                && mstate.X > positions[0].X
                && mstate.X < positions[0].X + selector.Width)
            {
                int option = (int)(mstate.Y - menuPosition.Y - positions[0].Y + 39) / 77;
                if (option >= 0 && option < positions.Length) currentOption = option;
            }

            //Quit
            if (gstate.IsButtonDown(Buttons.B)
                || gstate.IsButtonDown(Buttons.Start)
                || kstate.IsKeyDown(Keys.Escape))
            {
                if (!quitPressed)
                {
                    quitPressed = true;
                    Game1.currentState = MenuState.GAME;
                }
            }
            else
                quitPressed = false;

            //Button control
            if (kstate.IsKeyDown(Keys.Up) || gstate.IsButtonDown(Buttons.LeftThumbstickUp))
            {
                if (!dirPressed)
                {
                    dirPressed = true;
                    currentOption--;
                    if (currentOption < 0)
                        currentOption = 0;
                    else
                        Game1.soundbank.PlayCue("MenuClick");
                }
            }
            else if (kstate.IsKeyDown(Keys.Down) || gstate.IsButtonDown(Buttons.LeftThumbstickDown))
            {
                if (!dirPressed)
                {
                    dirPressed = true;
                    currentOption++;
                    if (currentOption > positions.Length)
                        currentOption = positions.Length;
                    else
                        Game1.soundbank.PlayCue("MenuClick");
                }
            }
            else
                dirPressed = false;

            //Forbid resume if dead
            if (Game1.player.Die && currentOption == 0) currentOption = 1;

            if (mstate.LeftButton == ButtonState.Pressed
                || kstate.IsKeyDown(Keys.Enter)
                || gstate.IsButtonDown(Buttons.A))
            {
                if (!selectPressed)
                {
                    selectPressed = true;
                    switch (currentOption)
                    {
                        case 0:
                            Game1.currentState = MenuState.GAME;
                            break;
                        case 1:
                            if (GenePool.SaveBot())
                            {
                                MessageDisplay.Clear();
                                MessageDisplay.PostMessage("Product export completed.");
                            }
                            else
                            {
                                MessageDisplay.Clear();
                                MessageDisplay.PostMessage("No product to export.");
                            }
                            break;
                        case 2:
                            Game1.currentState = MenuState.MAINMENU;
                            break;
                    }
                }
            }
            else
                selectPressed = false;

            oldMousePos = new Vector2(mstate.X, mstate.Y);
        }

        public static void Draw(SpriteBatch spriteBatch)
        {
            spriteBatch.Draw(
                bg,
                menuPosition,
                Color.White);

            spriteBatch.Draw(
                selector,
                menuPosition + positions[currentOption],
                Color.White);
        }
    }
}
