﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;

namespace Primeval
{
    abstract class Projectile
    {
        #region Static
        private static List<Projectile> projectiles;

        static Projectile()
        {
            projectiles = new List<Projectile>();
        }

        public static void Reset()
        {
            projectiles.Clear();
        }

        public static void Add(Projectile r)
        {
            projectiles.Add(r);
        }

        public static void UpdateAll(GameTime gameTime)
        {
            for (int c = projectiles.Count - 1; c >= 0; c--)
            {
                projectiles[c].Update(gameTime);
                if (projectiles[c].die) projectiles.RemoveAt(c);
            }
        }

        public static void DrawAll(SpriteBatch spriteBatch)
        {
            foreach (Projectile r in projectiles) r.Draw(spriteBatch);
        }
        #endregion

        protected static Texture2D bullet;
        protected static Texture2D rocket;

        protected Vector2 position;

        protected Vector2 velocity;

        protected float damage;

        public bool die;

        //Checks so that entity firing doesn't get hit immediately
        private Bot passing;
        private bool passingPlayer;

        protected Bot owner;

        protected abstract float radius { get; }

        public Projectile(float velocity, float damage, Vector2 direction)
        {
            this.velocity = velocity * Vector2.Normalize(direction);
            this.damage = damage;
            this.position = Game1.player.position;
            this.passingPlayer = true;

            Add(this);
        }

        public Projectile(float velocity, float damage, Vector2 direction, Bot owner)
        {
            this.velocity = velocity * Vector2.Normalize(direction);
            this.damage = damage;
            this.position = owner.position;
            this.passing = owner;
            this.owner = owner;

            Add(this);
        }

        public static void LoadContent()
        {
            bullet = Game1.content.Load<Texture2D>("bullet");
            rocket = Game1.content.Load<Texture2D>("rocket");
        }

        public virtual void Update(GameTime gameTime)
        {
            position += velocity * (float)gameTime.ElapsedGameTime.TotalSeconds;

            //Check collision
            bool foundpassing = false;
            foreach (Bot b in Bot.bots)
            {
                if (Vector2.Distance(position, b.position) < radius + b.radius)
                {
                    if (b == passing)
                        foundpassing = true;
                    else
                    {
                        b.Damage(damage);
                        Die(Vector2.Normalize(position - b.position));
                    }
                }
            }
            if (!foundpassing) passing = null;

            //With player
            if (Vector2.Distance(position, Game1.player.position) < radius + Player.radius)
            {
                if (!passingPlayer)
                {
                    Game1.player.Damage(damage);
                    Die(Vector2.Normalize(position - Game1.player.position));
                    if (owner != null) owner.DealtDamage(damage);
                }
            }
            else
                passingPlayer = false;

            //Out of bounds
            //TODO: explode normal
            if (!Game1.map.Contains(new Point((int)position.X, (int)position.Y))) Die(Vector2.Zero);
        }

        protected virtual void Die(Vector2 normal)
        {
            die = true;
        }

        public virtual void Draw(SpriteBatch spriteBatch)
        {

        }
    }
}
